@@ -4,7 +4,7 @@ import pandas as pd
 from quasinet.qnet import Qnet, qdistance, load_qnet, qdistance_matrix
 from quasinet.qsampling import qsample, targeted_qsample
 
-qnet=load_qnet('results/PTSD_cognet_test.joblib')
+qnet=load_qnet('../results/PTSD_cognet_test.joblib')
 w = 304
 h = w
 p_all = pd.read_csv("tmp_samples_as_strings.csv", header=None).values.astype(str)[:]
